pub enum AcceptError {
Full,
Engine(Error),
}Expand description
Error returned when a server endpoint cannot accept a peer.
Variants
Full
All peer slots are occupied.
Engine(Error)
The peer engine failed to queue the endpoint hello message.